meteor = {}

-- __index is essentially a backup plan, in case you try to access a key that doesn't have a value in the given table.
meteor.__index = meteor
-- It can be a function or a table. You don't need to understand it right now, though.
-- In this case, accessing a nonexistent value will simply cause it to return the parent table ("meteor").

meteorList = {} 

function meteor.new(object)
  -- A Metatable is another "backup plan" that can change the way a table behaves.
  -- Like for example: adding two tables together. Normally that doesn't work, but it can with metatables and metamethods.
  local obj = setmetatable(object or {}, meteor)
  -- Here we set a metatable for the "object" table, or if one isn't defined then we create a new table. The metatable is the parent table ("meteor").
  
  obj.xspd = math.random(-3,3)
  obj.yspd = math.random(3,5)
  obj.sides = math.random(5,9)
  obj.size = math.random(30, 70)
  local rnd = (math.random(0,50)*16)
  
  -- Writing "obj.x/y or _" allows us to either use a custom x,y for each meteor, or let the RNG pick random ones for us.
  -- See the "love.mousepressed" callback at the bottom of main.lua for an example.
  obj.x = obj.x or rnd
  obj.y = obj.y or 0
  
  obj.pic = love.graphics.newImage("Sprites/Meteor.gif")
  
  -- Put our object into the list of meteors.
  table.insert(meteorList, obj)
  return obj
end

function meteor:update(dt)
  self.x = self.x + self.xspd 
  self.y = self.y + self.yspd
  
  -- Check each meteor to see if it's below the ground, and delete it if so. I was lazy so I just picked an arbitrary number for the ground y, feel free to change it if you ever need to (you probably will).
  for i,meteor in pairs(meteorList) do
    if meteor.y > 400 then
      table.remove(meteorList, i) 
    end  

    -- This was my attempt at collsions \/
  --  if self.x < player.x + player.pic:getWidth() and self.y < player.y + player.pic:getHeight() and self.x + self.pic:getWidth() < player.x and self.y + self.pic:getHeight() > player.y  then
  --    meteor.new()
  --  end
  end
end

function meteor:draw()
  love.graphics.setColor(255,255,255)
  love.graphics.draw(self.pic, self.x, self.y, 0, 4)
end

-- This wizardry here allows us to use the table as if it were a function. You don't need it, but in this case it allows you to simply write "meteor()" instead of "meteor.new()" if you want to. That's it.
setmetatable(meteor, { __call = function(_, ...) return meteor.new(...) end})